@@ -3,7 +3,7 @@
 #
 # See LICENSE file for full license.
 
-from . import AWSObject
+from . import AWSObject, Ref
 from .validators import integer
 
 
@@ -14,7 +14,8 @@ class CacheCluster(AWSObject):
         'AutoMinorVersionUpgrade': (bool, False),
         'CacheNodeType': (basestring, True),
         'CacheParameterGroupName': (basestring, False),
-        'CacheSecurityGroupNames': (list, True),
+        'CacheSecurityGroupNames': ([basestring, Ref], True),
+        'CacheSubnetGroupName': (basestring, False),
         'Engine': (basestring, True),
         'EngineVersion': (basestring, False),
         'NotificationTopicArn': (basestring, False),
@@ -22,6 +23,8 @@ class CacheCluster(AWSObject):
         'Port': (int, False),
         'PreferredAvailabilityZone': (basestring, False),
         'PreferredMaintenanceWindow': (basestring, False),
+        'SnapshotArns': ([basestring, Ref], False),
+        'VpcSecurityGroupIds': ([basestring, Ref], False),
     }
 
 
