@@ -3,7 +3,7 @@
 #
 # See LICENSE file for full license.
 
-from . import AWSHelperFn, AWSObject, AWSProperty
+from . import AWSHelperFn, AWSObject, AWSProperty, Ref
 from .validators import integer
 try:
     from awacs.aws import Policy
@@ -29,11 +29,11 @@ class AccessKey(AWSObject):
 
 class PolicyProps():
     props = {
-        'Groups': ([basestring], False),
+        'Groups': ([basestring, Ref], False),
         'PolicyDocument': (policytypes, True),
         'PolicyName': (basestring, True),
-        'Roles': ([basestring], False),
-        'Users': ([basestring], False),
+        'Roles': ([basestring, Ref], False),
+        'Users': ([basestring, Ref], False),
     }
 
 
