@@ -8,6 +8,8 @@ from .validators import boolean
 
 
 class DBInstance(AWSObject):
+    type = "AWS::RDS::DBInstance"
+
     props = {
         'AllocatedStorage': (basestring, True),
         'AutoMinorVersionUpgrade': (bool, False),
@@ -33,36 +35,25 @@ class DBInstance(AWSObject):
         'VPCSecurityGroups': ([basestring, AWSHelperFn], False),
     }
 
-    def __init__(self, name, **kwargs):
-        self.type = "AWS::RDS::DBInstance"
-        sup = super(DBInstance, self)
-        sup.__init__(name, self.type, "Properties", self.props, **kwargs)
-
 
 class DBParameterGroup(AWSObject):
+    type = "AWS::RDS::DBParameterGroup"
+
     props = {
         'Description': (basestring, False),
         'Family': (basestring, False),
         'Parameters': (dict, False),
     }
 
-    def __init__(self, name, **kwargs):
-        self.type = "AWS::RDS::DBParameterGroup"
-        sup = super(DBParameterGroup, self)
-        sup.__init__(name, self.type, "Properties", self.props, **kwargs)
-
 
 class DBSubnetGroup(AWSObject):
+    type = "AWS::RDS::DBSubnetGroup"
+
     props = {
         'DBSubnetGroupDescription': (basestring, True),
         'SubnetIds': (list, True),
     }
 
-    def __init__(self, name, **kwargs):
-        self.type = "AWS::RDS::DBSubnetGroup"
-        sup = super(DBSubnetGroup, self)
-        sup.__init__(name, self.type, "Properties", self.props, **kwargs)
-
 
 class RDSSecurityGroup(AWSProperty):
     props = {
@@ -74,19 +65,18 @@ class RDSSecurityGroup(AWSProperty):
 
 
 class DBSecurityGroup(AWSObject):
+    type = "AWS::RDS::DBSecurityGroup"
+
     props = {
         'EC2VpcId': (basestring, False),
         'DBSecurityGroupIngress': (list, True),
         'GroupDescription': (basestring, True),
     }
 
-    def __init__(self, name, **kwargs):
-        self.type = "AWS::RDS::DBSecurityGroup"
-        sup = super(DBSecurityGroup, self)
-        sup.__init__(name, self.type, "Properties", self.props, **kwargs)
-
 
 class DBSecurityGroupIngress(AWSObject):
+    type = "AWS::RDS::DBSecurityGroupIngress"
+
     props = {
         'CIDRIP': (basestring, False),
         'DBSecurityGroupName': (basestring, True),
@@ -94,8 +84,3 @@ class DBSecurityGroupIngress(AWSObject):
         'EC2SecurityGroupName': (basestring, True),
         'EC2SecurityGroupOwnerId': (basestring, True),
     }
-
-    def __init__(self, name, **kwargs):
-        self.type = "AWS::RDS::DBSecurityGroupIngress"
-        sup = super(DBSecurityGroupIngress, self)
-        sup.__init__(name, self.type, "Properties", self.props, **kwargs)
