@@ -16,6 +16,11 @@ class Queue(AWSObject):
     type = "AWS::SQS::Queue"
 
     props = {
+        'DelaySeconds': (integer, False),
+        'MaximumMessageSize': (integer, False),
+        'MessageRetentionPeriod': (integer, False),
+        'QueueName': (basestring, False),
+        'ReceiveMessageWaitTimeSeconds': (integer, False),
         'VisibilityTimeout': (integer, False),
     }
 
